@@ -3,8 +3,8 @@
 ;; Copyright © 2020, by Sebastian Meisel
 
 ;; Author: Sebastian Meisel <sebastian.meisel@gmail.com>
-;; Package-Version: 20250922.1323
-;; Package-Revision: c5a6127ad831
+;; Package-Version: 20260110.1949
+;; Package-Revision: 0b9294f8f2b5
 ;; Created:  November 12, 2023
 ;; Keywords: unix
 ;; Homepage: https://github.com/SebastianMeisel/journalctl-mode
@@ -419,6 +419,7 @@ It controls the formatting of the journal entries that are shown.")
     (journalctl-transient:--unit)
     (journalctl-transient:--user-unit)
     (journalctl-transient:--facility)
+    (journalctl-transient:--priority)
     ]
    ["Filters"
     (journalctl-transient:--since)
@@ -649,8 +650,8 @@ Move to next chunk when top of frame is reached."
     map)
   "Keymap for journalctl mode.")
 
-(defvar mode-line-process nil "Process status in the mode line.")
-(defvar font-lock-defaults nil "Defaults for Font Lock mode specified by the major mode.")
+(defvar mode-line-process)
+(defvar font-lock-defaults)
 
 ;;;###autoload
 (defun journalctl ()
